# `relationalai.std.graphs.Graph.nodes`

An attribute assigned to the graph's [`Nodes`](../Nodes/README.md) object.

## Returns

A [`Nodes`](../Nodes/README.md) object.

## Example

A graph's `.nodes` object represents its set of nodes:

```python
import relationalai as rai
from relationalai.std.graphs import Graph

# Create a model with a `Person` type.
model = rai.Model("socialNetwork")
Person = model.Type("Person")

# Add some people to the model and connect them with a `follows` property.
with model.rule():
    alice = Person.add(name="Alice")
    bob = Person.add(name="Bob")
    alice.set(follows=bob)

# Create a graph from the model add `Person` objects to its nodes.
graph = Graph(model)
graph.nodes.extend(Person)
```

See [`Nodes`](../Nodes/README.md) for more information.
